# cosipy

[![unit_tests](https://github.com/cositools/cosipy/actions/workflows/unit_tests.yml/badge.svg?branch=develop)](https://github.com/cositools/cosipy/actions/workflows/unit_tests.yml)
[![codecov](https://codecov.io/gh/cositools/cosipy/branch/develop/graph/badge.svg?token=FQGI2VG4OY)](https://codecov.io/gh/cositools/cosipy)

The cosipy library is [COSI](https://cosi.ssl.berkeley.edu)'s high-level analysis software.

The main repository is hosted in https://github.com/cositools/cosipy

For the cosipy installation and usage instructions please refer to the main [cosipy documentation](https://cositools.github.io/cosipy/).



